@@ -2,8 +2,8 @@
 Data persistance and pipelining tools
 """
 
-from dpipe._cached import CachedResultItem, cached, clear_cache  # noqa: F401
-from dpipe._dask import (  # noqa: F401
+from apipe._cached import CachedResultItem, cached, clear_cache  # noqa: F401
+from apipe._dask import (  # noqa: F401
     DelayedParameter,
     DelayedParameters,
     delayed_cached,
